@@ -5,7 +5,7 @@ use warnings;
 use parent qw(DataAccess::Broker);
 use DBI;
 use Gtk2::Ex::DbLinker::SqlADataManager;
-use Data::Dumper;
+# use Data::Dumper;
 use Carp 'croak';
 
 sub new {
