@@ -7,7 +7,7 @@ use Gtk2::Ex::DbLinker::Datasheet;
 use Log::Log4perl;
 use Forms::Dnav2;
 use Forms::Sflang2;
-use Data::Dumper;
+# use Data::Dumper;
 use Scalar::Util qw(weaken);
 
 sub new {
