@@ -267,8 +267,8 @@ sub on_apply_lst_clicked {
         langid    => $self->{langid},
         countryid => $self->{sf_list}->get_column_value('countryid')
     );
-    $self->{log}->debug( "old values", Dumper %old );
-    $self->{log}->debug( "new values", Dumper %h );
+    $self->{log}->debug( "old values", sub{ Dumper %old } );
+    $self->{log}->debug( "new values", sub {Dumper %h });
     my @pks = $dman->get_primarykeys;
 
 #a new row is created in Datasheet->apply  and the inserting flag is turn to 1 (not in Datasheet->insert)
